@@ -1,7 +1,6 @@
 summary.intReg <- function(object, ...) {
+   s <- NextMethod("summary", object, ...)
    estimate <- coefTable(coef(object), stdEr(object), object$param$df)
-   library(maxLik)
-   s <- maxLik:::summary.maxLik(object)
    s$estimate <- estimate
    s$param <- object$param
                            # supply the additional parameters
